@@ -70,6 +70,7 @@ class Overlay(QtWidgets.QWidget):
         # Init some stuffs
         self.draw_stack = []
         self.geometry_stack = []
+        self.is_hidden = False
         self.__overlay_painter = QtGui.QPainter()
 
         # Timer (necessary for update and triggering paintEvent)
@@ -82,6 +83,13 @@ class Overlay(QtWidgets.QWidget):
         self.__overlay_painter.begin(self)
         self.__overlay_painter.setRenderHint(QtGui.QPainter.Antialiasing)
 
+        if self.is_hidden:
+            if not self.isHidden():
+                self.hide()
+        else:
+            if self.isHidden():
+                self.show()
+
         if self.geometry_stack:
             self.setGeometry(*self.geometry_stack)
             self.geometry_stack.clear()
